@@ -13,9 +13,10 @@ int pthread_mutex_destroy(pthread_mutex_t *mutex)
 {
     init();
 
+    struct thread *t = find_thread(pthread_self());
     struct mutex *n = find_mutex(mutex);
 
-    fprintf(stderr, "destroy #%u\n", n->num);
+    fprintf(stderr, "[%u] mutex_destroy(%u)\n", t->num, n->num);
 
     return real_mutex_destroy(mutex);
 }
