@@ -8,6 +8,8 @@
 
 #include <unistd.h>
 
+#include "common.h"
+
 void *thread_func(void *p)
 {
     pthread_mutex_t *mutex = (pthread_mutex_t *)p;
@@ -47,3 +49,17 @@ int test_main()
 
     return 0;
 }
+
+char const test_results[] =
+    "[1] mutex_init(1, FAST)\n"
+    "[1] mutex_lock(1)\n"
+    "[2] started\n"
+    "[2] mutex_lock(1) <waiting for thread 1> ...\n"
+    "[1] mutex_unlock(1)\n"
+    "[2] ... mutex_lock(1)\n"
+    "[2] mutex_unlock(1)\n"
+    "[2] finished (normal exit)\n"
+    "[1] mutex_destroy(1)\n";
+
+unsigned int const test_results_len = sizeof test_results;
+bool const test_result_timeout = false;
